OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migrare în progres. Așteaptă până când migrarea este finalizată",
    "Migration started …" : "Migrarea a început...",
    "Saved" : "Salvat",
    "Not saved" : "Nu a fost salvat",
    "Sending…" : "Se trimite...",
    "Email sent" : "Mesajul a fost expediat",
    "Private" : "Privat",
    "Public" : "Public",
    "Verify" : "Verifică",
    "Verifying …" : "Se verifică ...",
    "Unable to change password" : "Imposibil de schimbat parola",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "An error occurred while changing your language. Please reload the page and try again." : "A apărut o eroare la schimbarea limbii. Reîncărcați pagina și încercați din nou.",
    "An error occurred while changing your locale. Please reload the page and try again." : "A apărut o eroare la schimbarea locației. Reîncărcați pagina și încercați din nou.",
    "Select a profile picture" : "Selectează o imagine de profil",
    "Week starts on {fdow}" : "Săptămâna începe {fdow}",
    "Groups" : "Grupuri",
    "Group list is empty" : "Lista de grupuri este goală",
    "Unable to retrieve the group list" : "Nu s-a putut obține lista de grupuri",
    "{actor} added you to group {group}" : "{actor} te-a adăugat în grupul {group}",
    "You added {user} to group {group}" : "Ai adăugat {user} în grupul {group}",
    "{actor} added {user} to group {group}" : "{actor} a adăugat pe {user} în grupul {group}",
    "An administrator added you to group {group}" : "Un administrator te-a adăugat în grupul {group}",
    "An administrator added {user} to group {group}" : "Un administrator a adăugat pe {user} în grupul {group} ",
    "{actor} removed you from group {group}" : "{actor} te-a eliminat din grupul {group}",
    "You removed {user} from group {group}" : "Ai eliminat {user} din grupul {group}",
    "An administrator removed you from group {group}" : "Un administrator te-a eliminat din grupul {group}",
    "An administrator removed {user} from group {group}" : "Un administrator a eliminat {user} din groupul {group}",
    "{actor} changed your password" : "{actor} ți-a schimbat parola",
    "You changed your password" : "Ți-ai schimbat parola",
    "Your password was reset by an administrator" : "Parola dumneavoastră a fost resetată de un administrator",
    "{actor} changed your email address" : "{actor} ți-a schimbat adresa de email",
    "You changed your email address" : "Ți-ai schimbat adresa de email",
    "Your email address was changed by an administrator" : "Adresa ta de email a fost modificată de un administrator",
    "You created app password \"{token}\"" : "Ai creat parola aplicației \"{token}\"",
    "You deleted app password \"{token}\"" : "Ai șters parola aplicației \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Ai redenumit parola aplicației \"{token}\" în \"{newToken}\"",
    "Security" : "Securitate",
    "You successfully logged in using two-factor authentication (%1$s)" : "Te-ai conectat cu succes utilizând autentificarea cu doi factori (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "O încercare de autentificare utilizând autentificarea cu doi factori a eșuat (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Parola </strong> sau <strong>mailul </strong>a fost modificat",
    "Couldn't remove app." : "Nu s-a putut înlătura aplicația.",
    "Couldn't update app." : "Aplicaţia nu s-a putut actualiza.",
    "Wrong password" : "Parolă greșită",
    "No user supplied" : "Nu a fost furnizat niciun utilizator",
    "Authentication error" : "Eroare la autentificare",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Furnizează o parolă administrativă de recuperare, altfel toate datele utilizatorilor vor fi pierdute",
    "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
    "Federated Cloud Sharing" : "Partajare federalizată cloud",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL utilizează o versiune %1$sneupdatată (%2$s). Vă rugăm să updatați sistemul de operare sau actualizați caracteristicile %3$scare nu funcționează în mod fiabil.",
    "Invalid SMTP password." : "Parolă SMTP invalidă.",
    "Email setting test" : "Test setări email",
    "Well done, %s!" : "Felicitări, %s!",
    "If you received this email, the email configuration seems to be correct." : "Daca primești acest mail, configurările de email au fost efectuate corect.",
    "Email could not be sent. Check your mail server log" : "Mesajul nu a putut fi trimis. Verifică logul serverului de mail.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : " A apărut o problemă la trimiterea emailului. Verifică-ți setărie. (Eroare: %s)",
    "You need to set your user email before being able to send test emails." : "Trebuie să îți setezi emailul de utilizator înainte de a putea să trimiți emailuri.",
    "Invalid mail address" : "Adresa mail invalidă",
    "Settings saved" : "Setările au fost salvate",
    "Unable to change full name" : "Nu s-a putut schimba numele complet",
    "Unable to change email address" : "Nu s-a putut schimba adresa email",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pentru a putea verifica contul de Twitter, postați următorul tweet (asigurați-vă că îl postați fără spații):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pentru a verifica site-ul dvs., stocați următorul conținut în root-ul siteului web la \".well-known / CloudIdVerificationCode.txt\" (asigurați-vă că textul complet este compus dintr-o singură linie):",
    "%1$s changed your password on %2$s." : "%1$s ți-a schimbat parola pe %2$s.",
    "Your password on %s was changed." : "Parola ta pe %s a fost modificată.",
    "Your password on %s was reset by an administrator." : "Parola ta pe %s a fost resetată de către un administrator.",
    "Password for %1$s changed on %2$s" : "Parola pentru %1$s modificată pe %2$s",
    "Password changed for %s" : "Parolă modificată pentru %s",
    "If you did not request this, please contact an administrator." : "Dacă nu ai solicitat aceasta, te rugăm să contactezi un administrator.",
    "Your email address on %s was changed." : "Adresa de mail pe %s a fost modificată.",
    "Your email address on %s was changed by an administrator." : "Adresa de mail pe %s a fost modificată de către un administrator.",
    "Email address for %1$s changed on %2$s" : "Adresa de mail pentru %1$s a fost modificată pe %2$s",
    "Email address changed for %s" : "Adresa de email schimbată în %s",
    "The new email address is %s" : "Adresa de email nouă este%s",
    "Your %s account was created" : "Contul tău %s a fost creat",
    "Welcome aboard" : "Bun venit la bord",
    "Welcome aboard %s" : "Bun venit la bord %s",
    "Your username is: %s" : "Utilizatorul tău este: %s",
    "Set your password" : "Setează parola",
    "Install Client" : "Instalează client",
    "Apps" : "Aplicații",
    "Settings" : "Setări",
    "Personal" : "Personal",
    "Administration" : "Administrare",
    "Additional settings" : "Setări adiționale",
    "Basic settings" : "Setări de bază",
    "Sharing" : "Partajare",
    "Personal info" : "Informații personale",
    "Create" : "Creează",
    "Delete" : "Șterge",
    "Unlimited" : "Nelimitată",
    "Verifying" : "Se verifică",
    "Enforce two-factor authentication" : "Forțează autentificarea cu doi factori",
    "Limit to groups" : "Limitează pentru grupuri",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Forțarea autentificării cu doi factori poate fi setată doar pentru anumite grupuri.",
    "Save changes" : "Salvează modificările",
    "All" : "Toate ",
    "No results" : "Niciun rezultat",
    "Update to {version}" : "Actualizare la {version}",
    "Remove" : "Șterge",
    "Disable" : "Dezactivați",
    "Visit website" : "Viziteaza pagina web",
    "Report a bug" : "Raportează un defect",
    "User documentation" : "Documentație utilizator",
    "Admin documentation" : "Documentație pentru administrare",
    "Developer documentation" : "Documentație pentru dezvoltatori",
    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
    "Device settings" : "Setările dispozitivului",
    "Allow filesystem access" : "Permite accesul la fișierele de sistem",
    "Rename" : "Redenumește",
    "Revoke" : "Revocă",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Aplicația Nextcloud pentru iOS",
    "Nextcloud Android app" : "Aplicația Nextcloud pentru Android",
    "Nextcloud Talk for iOS" : "Nextcloud Talk pentru iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk pentru Android",
    "This session" : "Această sesiune",
    "Device" : "Dispozitiv",
    "Last activity" : "Ultima activitate",
    "Devices & sessions" : "Dispozitive și sesiuni",
    "Error while deleting the token" : "Eroare de ștergere token",
    "App name" : "Numele aplicației",
    "Create new app password" : "Crează o nouă parolă pentru aplicație",
    "Username" : "Nume utilizator",
    "Password" : "Parolă",
    "Done" : "Realizat",
    "Copied!" : "S-a copiat!",
    "Copy" : "Copiază",
    "You do not have permissions to see the details of this user" : "Nu aveți permisiuni pentru a vedea detaliile acestui utilizator",
    "Cancel" : "Anulare",
    "{size} used" : "{size} folosită",
    "Display name" : "Nume afișat",
    "Email" : "Email",
    "Default language" : "Limba implicită",
    "Close" : "Închide",
    "Quota" : "Cotă",
    "Language" : "Limba",
    "All languages" : "Toate limbile",
    "Add" : "Adaugă",
    "Your apps" : "Aplicațiile tale",
    "Disabled apps" : "Aplicații inactive",
    "Updates" : "Actualizări",
    "Details" : "Detalii",
    "Add group" : "Adaugă grup",
    "Everyone" : "Toți",
    "Admins" : "Administratori",
    "Show user backend" : "Arată administrare utilizator",
    "Send email to new user" : "Trimite email către noul utilizator",
    "Enable" : "Activare",
    "The app will be downloaded from the app store" : "Aplicația va fi descărcată din magazin",
    "Never" : "Niciodată",
    "App update" : "Actualizare aplicație",
    "Administrator documentation" : "Documentație pentru administrare",
    "Documentation" : "Documentație",
    "Forum" : "Forum",
    "None" : "Niciuna",
    "Login" : "Autentificare",
    "Plain" : "Plain",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Server de email",
    "Open documentation" : "Deschide documentația",
    "Send mode" : "Modul de expediere",
    "Encryption" : "Încriptare",
    "From address" : "De la adresa",
    "mail" : "poștă",
    "Authentication method" : "Modul de autentificare",
    "Authentication required" : "Autentificare necesară",
    "Server address" : "Adresa server-ului",
    "Port" : "Portul",
    "Credentials" : "Detalii de autentificare",
    "SMTP Username" : "Nume utilizator SMTP",
    "SMTP Password" : "Parolă SMTP",
    "Save" : "Salvează",
    "Test email settings" : "Verifică setările de e-mail",
    "Send email" : "Expediază mesajul",
    "Security & setup warnings" : "Alerte de securitate & configurare",
    "All checks passed." : "Toate verificările s-au terminat fără erori.",
    "Version" : "Versiunea",
    "Server-side encryption" : "Criptare la nivel de server",
    "Enable server-side encryption" : "Activează criptarea pe server",
    "Please read carefully before activating server-side encryption: " : "Citește cu atenție înainte să activezi criptarea pe server:",
    "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
    "Enable encryption" : "Activează criptarea",
    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
    "Start migration" : "Pornește migrarea",
    "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
    "Expire after " : "Expiră după",
    "days" : "zile",
    "Enforce expiration date" : "Impune data de expirare",
    "Allow users to share via link" : "Permite utilizatorilor să partajeze via link",
    "Allow public uploads" : "Permite încărcări publice",
    "Enforce password protection" : "Impune protecția prin parolă",
    "Allow resharing" : "Permite repartajarea",
    "Allow sharing with groups" : "Permite partajarea cu grupuri",
    "Exclude groups from sharing" : "Exclude grupuri de la partajare",
    "Profile picture" : "Imagine de profil",
    "Upload new" : "Încarcă una nouă",
    "Select from Files" : "Selectează din fișiere",
    "Remove image" : "Înlătură imagine",
    "png or jpg, max. 20 MB" : "png sau jpg, max. 20 MB",
    "Choose as profile picture" : "Alege ca imagine de profil",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Utilizezi <strong>%1$s</strong> din <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "Nume complet",
    "Your email address" : "Adresa ta de email",
    "No email address set" : "Fără adresă de email setată",
    "For password reset and notifications" : "Pentru resetare parolă și notificări",
    "Phone number" : "Număr telefon",
    "Your phone number" : "Numărul tău de telefon",
    "Address" : "Adresă",
    "Your postal address" : "Adresă poștală",
    "Website" : "Site web",
    "Link https://…" : "Link https://…",
    "Twitter" : "Twitter",
    "Help translate" : "Ajută la traducere",
    "Current password" : "Parola curentă",
    "New password" : "Noua parolă",
    "Change password" : "Schimbă parola",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "A apărut o eroare. Te rugăm să uploadezi un certificat PEM în format ASCII.",
    "Valid until {date}" : "Valabil până la {date}",
    "Local" : "Local",
    "Only visible to local users" : "Vizibil userilor locali",
    "Only visible to you" : "Vizibil doar pentru tine",
    "Contacts" : "Contacte",
    "Visible to local users and to trusted servers" : "Vizibil userilor locali si serverelor de încredere",
    "Will be synced to a global and public address book" : "Va fi sincronizat cu o agendă de adrese publice și globale",
    "by" : "de",
    "SSL Root Certificates" : "Certificate SSL rădăcină",
    "Common Name" : "Nume comun",
    "Valid until" : "Valabil până la",
    "Issued By" : "Emis de",
    "Valid until %s" : "Valabil până la %s",
    "Import root certificate" : "Importă certificat rădăcină",
    "Execute one task with each page loaded" : "Execută o sarcină la fiecare pagină încărcată"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
